@@ -121,7 +121,8 @@ bool WebcamControl::play(Device *device)
     }
 
     auto source = QGst::Bin::fromDescription(QLatin1String("v4l2src device=") + device->path());
-    auto bin = QGst::Bin::fromDescription("videobalance name=video_balance ! gamma name=gamma ! videoflip video-direction=horiz");
+    //videoflip: use video-direction=horiz, method is deprecated, not changing now because video-direction doesn't seem to be available on gstreamer 1.8 which is still widely used
+    auto bin = QGst::Bin::fromDescription("videobalance name=video_balance ! gamma name=gamma ! videoflip method=4");
     m_gamma = bin->getElementByName("gamma");
     m_videoBalance = bin->getElementByName("video_balance");
 
